@@ -1,29 +1,34 @@
 """
 Utility functions
 """
+
 import logging
 from typing import List, Tuple, Dict
 
+import matplotlib
 import matplotlib.patches as m_patches
 import matplotlib.transforms as trn
 import numpy as np
 from matplotlib.path import Path as mPath
 
+from matplotlib.axes import Axes
+from matplotlib.artist import Artist
+
 _logger = logging.getLogger(__name__)
 
-RATIO_OPTIONS = {'golden_ratio', 'equal', 'from_rows'}
+RATIO_OPTIONS = {"golden_ratio", "equal", "from_rows"}
 
 
 def add_values_to_bars(
-        axis,
-        bar_type='bar',
-        position='c',
-        label_format='{:.0f}',
-        x_offset=0,
-        y_offset=0,
-        color='k',
-        horizontalalignment='center',
-        verticalalignment='center',
+    axis,
+    bar_type="bar",
+    position="c",
+    label_format="{:.0f}",
+    x_offset=0,
+    y_offset=0,
+    color="k",
+    horizontalalignment="center",
+    verticalalignment="center",
 ):
     """
     Add the values of the bars as number in the center
@@ -34,7 +39,7 @@ def add_values_to_bars(
 
     Parameters
     ----------
-    axis: `mpl.pyplot.axes.Axes` object
+    axis: `matplotlib.pyplot.axes.Axes` object
         Axis containing the bar plot
     bar_type: {"bar", "barh"}
         Direction of the bars. Default = "bar", meaning vertical bars. Alternatively, you need to
@@ -68,19 +73,19 @@ def add_values_to_bars(
         ww = b.x1 - b.x0
 
         # determine the position of the text
-        if position == 'c':
+        if position == "c":
             # center
             (px, py) = (cx, cy)
-        elif position == 't':
+        elif position == "t":
             # top
             (px, py) = (cx, cy + hh / 2)
-        elif position == 'b':
+        elif position == "b":
             # bottom
             (px, py) = (cx, cy - hh / 2)
-        elif position == 'l':
+        elif position == "l":
             # left
             (px, py) = (cx - ww / 2, cy)
-        elif position == 'r':
+        elif position == "r":
             # right
             (px, py) = (cx + ww / 2, cy)
         else:
@@ -90,9 +95,9 @@ def add_values_to_bars(
         (px, py) = (px + x_offset, py + y_offset)
 
         # determine the value of the bar
-        if bar_type == 'bar':
+        if bar_type == "bar":
             value = hh
-        elif bar_type == 'barh':
+        elif bar_type == "barh":
             value = ww
         else:
             raise ValueError(f"type = {bar_type} not recognised. Please check")
@@ -111,17 +116,17 @@ def add_values_to_bars(
 
 
 def add_cbs_logo_to_plot(
-        fig,
-        axes=None,
-        margin_x_in_mm=6.0,
-        margin_y_in_mm=6.0,
-        x0=0,
-        y0=0,
-        width=None,
-        height=None,
-        zorder_start=1,
-        fillcolor='cbs:highchartslichtgrijs',
-        edgecolor='cbs:logogrijs',
+    fig,
+    axes=None,
+    margin_x_in_mm=6.0,
+    margin_y_in_mm=6.0,
+    x0=0,
+    y0=0,
+    width=None,
+    height=None,
+    zorder_start=1,
+    fillcolor="cbs:highchartslichtgrijs",
+    edgecolor="cbs:logogrijs",
 ):
     """
     Add the CBS logo to the plot.
@@ -381,21 +386,21 @@ def _get_cbs_logo_points(logo_width_in_mm=3.234, rrcor=0.171):
 
 
 def add_axis_label_background(
-        fig,
-        axes,
-        alpha=1,
-        margin=0.05,
-        x0=None,
-        y0=None,
-        loc='east',
-        radius_corner_in_mm=1,
-        logo_margin_x_in_mm=1,
-        logo_margin_y_in_mm=1,
-        add_logo=True,
-        aspect=None,
-        backgroundcolor='cbs:highchartslichtgrijs',
-        logo_fillcolor='cbs:highchartslichtgrijs',
-        logo_edgecolor='cbs:logogrijs',
+    fig,
+    axes,
+    alpha=1,
+    margin=0.05,
+    x0=None,
+    y0=None,
+    loc="east",
+    radius_corner_in_mm=1,
+    logo_margin_x_in_mm=1,
+    logo_margin_y_in_mm=1,
+    add_logo=True,
+    aspect=None,
+    backgroundcolor="cbs:highchartslichtgrijs",
+    logo_fillcolor="cbs:highchartslichtgrijs",
+    logo_edgecolor="cbs:logogrijs",
 ):
     """
     Add a background to the axis labels.
@@ -453,7 +458,7 @@ def add_axis_label_background(
         axes.transAxes.inverted()
     )
 
-    if loc == 'east':
+    if loc == "east":
         if x0 is None:
             x0 = bbox_axi.x0 - margin * bbox_axi.width
         x1 = 0
@@ -461,7 +466,7 @@ def add_axis_label_background(
         y0 = 0
         y1 = 1
 
-    elif loc == 'south':
+    elif loc == "south":
         x0 = 0
         x1 = 1
 
@@ -480,11 +485,11 @@ def add_axis_label_background(
     _logger.debug(f"Adding rectangle with width {width} and height {height}")
 
     # eerste vierkant zorgt voor rechte hoeken aan de rechterkant
-    if loc == 'east':
+    if loc == "east":
         rec_p = (x0 + width / 2, y0)
         rec_w = width / 2
         rec_h = height
-    elif loc == 'south':
+    elif loc == "south":
         rec_p = (x0, y0 + height / 2)
         rec_w = width
         rec_h = height / 2
@@ -523,7 +528,7 @@ def add_axis_label_background(
         transform=fig.transFigure,
         zorder=0,
     )
-    p2.set_boxstyle('round', pad=pad)
+    p2.set_boxstyle("round", pad=pad)
     p2.set_transform(axes.transAxes)
     p2.set_clip_on(False)
 
@@ -545,33 +550,38 @@ def add_axis_label_background(
         )
 
 
-def clean_up_artists(axis, artist_list):
+def remove_artists(axis: Axes, artists: list[Artist]) -> None:
     """
-    try to remove the artists stored in the artist list belonging to the 'axis'.
-    :param axis: clean artists belonging to these axis
-    :param artist_list: list of artists to remove
-    :return: nothing
-    """
-    for artist in artist_list:
-        try:
-            # fist attempt: try to remove a collection of contours for instance
-            while artist.collections:
-                for col in artist.collections:
-                    artist.collections.remove(col)
-                    try:
-                        axis.collections.remove(col)
-                    except ValueError:
-                        pass
+    Remove artists from an axis.
 
-                artist.collections = []
-                axis.collections = []
+    Parameters
+    ----------
+    axis : Axes
+        The axis from which to remove artists.
+    artists : list[Artist]
+        A list of artists to be removed.
+
+    Returns
+    -------
+    None
+    """
+    for artist in artists:
+        # Try to remove the artist from the axis
+        try:
+            artist.remove()
         except AttributeError:
             pass
 
-        # second attempt, try to remove the text
+        # Try to remove the artist from the axis collections
         try:
-            artist.remove()
-        except (AttributeError, ValueError):
+            while artist.collections:
+                for collection in artist.collections:
+                    artist.collections.remove(collection)
+                    try:
+                        axis.collections.remove(collection)
+                    except ValueError:
+                        pass
+        except AttributeError:
             pass
 
 
@@ -584,26 +594,22 @@ def format_thousands_label(value: float, _: object) -> str:
     value : float
         The value to format.
     _ : object
-        An unused parameter, only present to match the signature for a FormatStrFormatter.
+        Unused parameter, only present to match the signature for a FormatStrFormatter.
 
     Returns
     -------
     str
-        The formatted value with spaces as a thousand separator.
-
-    Examples
-    --------
-    >>> format_thousands_label(1234, None)
-    '1 234'
-    >>> format_thousands_label(1234567.89, None)
-    '1 234 567`
+        Formatted value with spaces as a thousand separator.
     """
-    return '{:0,d}'.format(int(value)).replace(',', ' ')
+    int_value = int(value)
+    return "{:,}".format(int_value).replace(",", " ")
 
 
 def swap_legend_boxes(
-        handles: List[m_patches.Patch], labels: List[str], n_cols: int
-) -> Tuple[List[m_patches.Patch], List[str]]:
+    handles: List[matplotlib.artist.Artist],  # List of legend handles
+    labels: List[str],  # List of legend labels
+    n_cols: int  # Number of columns in the legend
+) -> Tuple[List[matplotlib.artist.Artist], List[str]]:
     """
     Rearrange legend handles and labels to match the order of the first row.
 
@@ -611,25 +617,25 @@ def swap_legend_boxes(
 
     Parameters
     ----------
-    handles : list of matplotlib.patches.Patch
+    handles : List[matplotlib.artist.Artist]
         The list of legend handles.
-    labels : list of str
+    labels : List[str]
         The list of legend labels.
     n_cols : int
         The number of columns in the legend.
 
     Returns
     -------
-    reordered_handles : list of matplotlib.patches.Patch
+    reordered_handles : List[matplotlib.artist.Artist]
         The rearranged list of legend handles.
-    reordered_labels : list of str
+    reordered_labels : List[str]
         The rearranged list of legend labels.
     """
-    reordered_handles = handles[:]
-    reordered_labels = labels[:]
+    reordered_handles: List[matplotlib.artist.Artist] = handles.copy()
+    reordered_labels: List[str] = labels.copy()
 
     if len(reordered_labels) != len(reordered_handles):
-        raise ValueError('Number of handles and labels must be equal.')
+        raise ValueError("Number of handles and labels must be equal.")
 
     rows_per_col: Dict[int, int] = {}
 
